@@ -18,10 +18,11 @@ from diff_cover import DESCRIPTION, VERSION
 from diff_cover.diff_reporter import GitDiffReporter
 from diff_cover.git_diff import GitDiffTool
 from diff_cover.git_path import GitPathTool
-from diff_cover.report_generator import HtmlReportGenerator, StringReportGenerator
+from diff_cover.report_generator import HtmlReportGenerator, StringReportGenerator, JsonReportGenerator
 from diff_cover.violationsreporters.violations_reporter import XmlCoverageReporter
 
 HTML_REPORT_HELP = "Diff coverage HTML output"
+JSON_REPORT_HELP = "Diff coverage JSON output"
 COMPARE_BRANCH_HELP = "Branch to compare"
 CSS_FILE_HELP = "Write CSS into an external file"
 FAIL_UNDER_HELP = "Returns an error code if coverage or quality score is below this value"
@@ -43,10 +44,11 @@ def parse_coverage_args(argv):
         {
             'coverage_xml': COVERAGE_XML,
             'html_report': None | HTML_REPORT,
+            'json_report': None | JSON_REPORT,
             'external_css_file': None | CSS_FILE,
         }
 
-    where `COVERAGE_XML`, `HTML_REPORT`, and `CSS_FILE` are paths.
+    where `COVERAGE_XML`, `HTML_REPORT`, `JSON_REPORT`, and `CSS_FILE` are paths.
 
     The path strings may or may not exist.
     """
@@ -59,7 +61,9 @@ def parse_coverage_args(argv):
         nargs='+'
     )
 
-    parser.add_argument(
+    output_format = parser.add_mutually_exclusive_group()
+
+    output_format.add_argument(
         '--html-report',
         metavar='FILENAME',
         type=str,
@@ -67,6 +71,14 @@ def parse_coverage_args(argv):
         help=HTML_REPORT_HELP
     )
 
+    output_format.add_argument(
+        '--json-report',
+        metavar='FILENAME',
+        type=str,
+        default=None,
+        help=JSON_REPORT_HELP
+    )
+
     parser.add_argument(
         '--external-css-file',
         metavar='FILENAME',
@@ -142,6 +154,7 @@ def parse_coverage_args(argv):
 
 def generate_coverage_report(coverage_xml, compare_branch,
                              html_report=None, css_file=None,
+                             json_report=None,
                              ignore_staged=False, ignore_unstaged=False,
                              exclude=None, src_roots=None, diff_range_notation=None):
     """
@@ -167,6 +180,11 @@ def generate_coverage_report(coverage_xml, compare_branch,
             with open(css_file, "wb") as output_file:
                 reporter.generate_css(output_file)
 
+    elif json_report is not None:
+        reporter = JsonReportGenerator(coverage, diff)
+        with open(json_report, "wb") as output_file:
+            reporter.generate_report(output_file)
+
     reporter = StringReportGenerator(coverage, diff)
     output_file = sys.stdout if six.PY2 else sys.stdout.buffer
 
@@ -193,6 +211,7 @@ def main(argv=None, directory=None):
         arg_dict['coverage_xml'],
         arg_dict['compare_branch'],
         html_report=arg_dict['html_report'],
+        json_report=arg_dict['json_report'],
         css_file=arg_dict['external_css_file'],
         ignore_staged=arg_dict['ignore_staged'],
         ignore_unstaged=arg_dict['ignore_unstaged'],
